SessionInfo class
Constructors
- SessionInfo({required String scopeId, required String principalId, required String permissionVersion, SyncScopeMode scopeMode = SyncScopeMode.user})
-
const
-
SessionInfo.fromJson(Map<
String, Object?> json, {bool allowLegacy = false}) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- permissionVersion → String
-
final
- principalId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopeId → String
-
final
- scopeMode → SyncScopeMode
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sameScope(
SessionInfo other) → bool -
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited